@@ -18,7 +18,7 @@ except ImportError:
     import moves
     import server
 
-VERSION = '0.0.29'
+VERSION = '0.0.31'
 
 class Ansi:
     """ The terminal ansi chars """
@@ -41,22 +41,27 @@ class Ansi:
 class Piece:
     """ Each piece in the chess board """
 
-    PAWN = 'pawn'
-    KING = 'king'
-    QUEEN = 'queen'
-    KNIGHT = 'knight'
-    BISHOP = 'bishop'
-    ROCK = 'rock'
+    # Identifiers for pieces
+    PAWN = 0
+    KING = 1
+    QUEEN = 2
+    KNIGHT = 3
+    BISHOP = 4
+    ROOK = 5
 
+    # Icons for each type of piece for showing in the render output
     ICONS = {
-        'pawn': 'pawn',
-        'king': 'king',
-        'queen': 'queen',
-        'knight': 'knight',
-        'bishop': 'bishop',
-        'rock': 'rock',
+        PAWN: 'p',
+        KING: 'k',
+        QUEEN: 'q',
+        KNIGHT: 'n',
+        BISHOP: 'b',
+        ROOK: 'r',
     }
 
+    # used as a cache for `get_longer_icon_len`
+    ICONS_MAX_LEN = None
+
     def __init__(self, name: str, color: str):
         self.name = name
         self.color = color
@@ -79,10 +84,10 @@ class Piece:
         result = []
         if self.name == Piece.PAWN:
             result = moves.pawn_move(self, game, src)
-        elif self.name == Piece.ROCK:
-            result = moves.rock_move(self, game, src)
+        elif self.name == Piece.ROOK:
+            result = moves.rook_move(self, game, src)
         elif self.name == Piece.QUEEN:
-            result = [*moves.rock_move(self, game, src), *moves.bishop_move(self, game, src)]
+            result = [*moves.rook_move(self, game, src), *moves.bishop_move(self, game, src)]
         elif self.name == Piece.KING:
             result = moves.king_move(self, game, src)
         elif self.name == Piece.KNIGHT:
@@ -97,11 +102,33 @@ class Piece:
             return True
         return False
 
+    @staticmethod
+    def get_longer_icon_len():
+        """ Returns length of the longer item in the icons """
+        # check the cache
+        if Piece.ICONS_MAX_LEN is not None:
+            return Piece.ICONS_MAX_LEN
+
+        mx_len = 0
+        for k in Piece.ICONS:
+            if len(Piece.ICONS[k]) > mx_len:
+                mx_len = len(Piece.ICONS[k])
+        Piece.ICONS_MAX_LEN = mx_len
+
+        return Piece.ICONS_MAX_LEN
+
+    @staticmethod
+    def get_id_by_icon(icon):
+        """ Returns Id of the piece by icon """
+        for k in Piece.ICONS:
+            if Piece.ICONS[k] == icon:
+                return k
+
 class Game:
     """ The running game handler """
 
-    ROW_SEPARATOR = ('|-----------'*8) + '|\n'
-    CELL_WIDTH = 10
+    CELL_WIDTH = Piece.get_longer_icon_len() + 4
+    ROW_SEPARATOR = (('|' + ('-' * (CELL_WIDTH+1))) * 8) + '|\n'
     IS_TEST = False
 
     def __init__(self):
@@ -151,7 +178,7 @@ class Game:
                 elif i in (0, 7):
                     name = Piece.PAWN
                     if j in (0, 7):
-                        name = Piece.ROCK
+                        name = Piece.ROOK
                     elif j in (0, 3):
                         name = Piece.KING
                     elif j in (3 ,7):
@@ -232,13 +259,15 @@ class Game:
         if dst[0] in (0, 7) and src_p.name == Piece.PAWN:
             # this is a pawn and is moved to end of the board
             # player can select a new piece
-            allowed_items = (Piece.ROCK, Piece.KNIGHT, Piece.BISHOP, Piece.QUEEN)
-            err_msg = 'Error: please determine new piece type to convert pawn to: `mv x y > {' + ', '.join(allowed_items) + '}`'
+            allowed_items = (Piece.ROOK, Piece.KNIGHT, Piece.BISHOP, Piece.QUEEN)
+            allowed_items_hr = (Piece.ICONS[Piece.ROOK], Piece.ICONS[Piece.KNIGHT], Piece.ICONS[Piece.BISHOP], Piece.ICONS[Piece.QUEEN])
+            err_msg = 'Error: please determine new piece type to convert pawn to: `mv x y > {' + ', '.join(allowed_items_hr) + '}`'
             if convert_pawn_to is None:
                 return False, err_msg
-            elif convert_pawn_to not in allowed_items:
+            elif convert_pawn_to not in allowed_items_hr:
                 return False, err_msg
             else:
+                convert_pawn_to = Piece.get_id_by_icon(convert_pawn_to)
                 src_p = Piece(convert_pawn_to, src_p.color)
 
         self.board[src[0]][src[1]] = None
@@ -361,8 +390,8 @@ class Game:
         """ Returns list of dead items like this:
         {
             "black": {
-                "pawn": 3, # count
-                "rock": 1
+                Piece.ICONS[Piece.PAWN]: 3, # count
+                Piece.ICONS[Piece.ROOK]: 1
             },
             "white": {
                 # ...
@@ -420,7 +449,7 @@ class Game:
         output += (' ' * len(self.ROW_SEPARATOR)) + '\n'
 
         for i in range(1, 9):
-            output += (int(self.CELL_WIDTH/2) * ' ') + str(i) + (' ' * (int(self.CELL_WIDTH/2)+1))
+            output += ((self.CELL_WIDTH+1) * ' ') + str(i)
         output += '\n'
         i = 0
         for row in self.board:
@@ -428,7 +457,7 @@ class Game:
             j = 0
             for column in row:
                 if column is None:
-                    column_str = ' ' + str(i+1) + '-' + str(j+1)
+                    column_str = str(i+1) + '-' + str(j+1)
                     ansi_color = Ansi.GRAY
                     ansi_reset = Ansi.RESET
                 else:
@@ -526,33 +555,34 @@ GAME
 
     BASICS
 
-        when you run the game, you see something like this:
+        when you run the game, you will see something like this:
+
+               1      2      3      4      5      6      7      8
+             |------|------|------|------|------|------|------|------|
+           1 | w-r  | w-n  | w-b  | w-k  | w-q  | w-b  | w-n  | w-r  |
+             |------|------|------|------|------|------|------|------|
+           2 | w-p  | w-p  | w-p  | w-p  | w-p  | w-p  | w-p  | w-p  |
+             |------|------|------|------|------|------|------|------|
+           3 | 3-1  | 3-2  | 3-3  | 3-4  | 3-5  | 3-6  | 3-7  | 3-8  |
+             |------|------|------|------|------|------|------|------|
+           4 | 4-1  | 4-2  | 4-3  | 4-4  | 4-5  | 4-6  | 4-7  | 4-8  |
+             |------|------|------|------|------|------|------|------|
+           5 | 5-1  | 5-2  | 5-3  | 5-4  | 5-5  | 5-6  | 5-7  | 5-8  |
+             |------|------|------|------|------|------|------|------|
+           6 | 6-1  | 6-2  | 6-3  | 6-4  | 6-5  | 6-6  | 6-7  | 6-8  |
+             |------|------|------|------|------|------|------|------|
+           7 | b-p  | b-p  | b-p  | b-p  | b-p  | b-p  | b-p  | b-p  |
+             |------|------|------|------|------|------|------|------|
+           8 | b-r  | b-n  | b-b  | b-k  | b-q  | b-b  | b-n  | b-r  |
+             |------|------|------|------|------|------|------|------|
 
-        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
-        | w-rock    | w-knight  | w-bishop  | w-king    | w-queen   | w-bishop  | w-knight  | w-rock    |
-        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
-        | w-pawn    | w-pawn    | w-pawn    | w-pawn    | w-pawn    | w-pawn    | w-pawn    | w-pawn    |
-        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
-        |  3-1      |  3-2      |  3-3      |  3-4      |  3-5      |  3-6      |  3-7      |  3-8      |
-        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
-        |  4-1      |  4-2      |  4-3      |  4-4      |  4-5      |  4-6      |  4-7      |  4-8      |
-        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
-        |  5-1      |  5-2      |  5-3      |  5-4      |  5-5      |  5-6      |  5-7      |  5-8      |
-        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
-        |  6-1      |  6-2      |  6-3      |  6-4      |  6-5      |  6-6      |  6-7      |  6-8      |
-        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
-        | b-pawn    | b-pawn    | b-pawn    | b-pawn    | b-pawn    | b-pawn    | b-pawn    | b-pawn    |
-        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
-        | b-rock    | b-knight  | b-bishop  | b-king    | b-queen   | b-bishop  | b-knight  | b-rock    |
-        |-----------|-----------|-----------|-----------|-----------|-----------|-----------|-----------|
-                                                                                                        
         white Turn >>>
 
         The above content will be showed in the terminal. and there is a command input in the bottom. You should pass commands to that for running the game.
 
         Also there is white Turn. this means its turn of white team. if you do something, this will be changed to black Turn.
 
-        Also name of Pieces is <team>-<type>. for example b-queen (black queen) and w-king (white king).
+        Also name of Pieces is <team>-<type>. for example b-q (black queen) and w-k (white king).
 
         The location of cells is accessible with this pattern: <row>-<column> or <row>.<column>. For example 1-1 or 6.4.
         exit
